@@ -121,8 +121,6 @@ on_cut_menu_activate                   (GtkMenuItem     *menuitem,
    image_buf *ibuf = widget_get_image(GTK_WIDGET(menuitem));
    g_assert(ibuf);
    image_buf_cut(ibuf);
-
-
 }
 
 
@@ -133,7 +131,6 @@ on_copy_menu_activate                  (GtkMenuItem     *menuitem,
    image_buf *ibuf = widget_get_image(GTK_WIDGET(menuitem));
    g_assert(ibuf);
    image_buf_copy(ibuf);
-
 }
 
 
@@ -154,17 +151,13 @@ on_clear_menu_activate                 (GtkMenuItem     *menuitem,
    image_buf *ibuf = widget_get_image(GTK_WIDGET(menuitem));
    g_assert(ibuf);
    if (ibuf->num_pts)
+   {
       image_buf_delete(ibuf);
+   }
    else
+   {
       image_buf_clear(ibuf);
-}
-
-
-void
-on_properties_menu_activate            (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
+   }
 }
 
 
@@ -175,8 +168,9 @@ on_flip_x_axis_menu_activate           (GtkMenuItem     *menuitem,
    image_buf *ibuf = widget_get_image(GTK_WIDGET(menuitem));
    BEGIN_BUSY_CURSOR
    image_buf_force_select_region(ibuf); /* for now */
-   
+    
    image_buf_flip_x_region(ibuf);
+   ibuf->num_pts = 0;              /* to fix clear */
    END_BUSY_CURSOR
 }
 
@@ -190,6 +184,7 @@ on_flip_y_axis_menu_activate           (GtkMenuItem     *menuitem,
    image_buf_force_select_region(ibuf); /* for now */
    
    image_buf_flip_y_region(ibuf);
+   ibuf->num_pts = 0;              /* to fix clear */
    END_BUSY_CURSOR
 
 }
@@ -262,14 +257,6 @@ on_rotate_menu_activate                (GtkMenuItem     *menuitem,
 }
 
 
-void
-on_crop_to_region_menu_activate        (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
 void
 on_reset_menu_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -469,39 +456,6 @@ on_convert_to_greyscale_menu_activate               (GtkMenuItem     *menuitem,
    END_BUSY_CURSOR
 }
 
-/* ---- */
-void
-on_fat_bits_menu_activate              (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
-void
-on_visible_grid_menu_activate          (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
-void
-on_snap_menu_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
-void
-on_snap_spacing_menu_activate          (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
 void
 on_change_background_menu_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -512,38 +466,6 @@ on_change_background_menu_activate     (GtkMenuItem     *menuitem,
 }
 
 
-void
-on_change_size1_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
-void
-on_undo_levels_menu_activate           (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
-void
-on_auto_crop_menu_activate             (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
-void
-on_change_zoom_menu_activate           (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
-{
-
-}
-
-
 void
 on_about_menu_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
@@ -1622,8 +1544,6 @@ void
 on_color_palette_entry_realize         (GtkWidget       *widget,
                                         gpointer         user_data)
 {
-   image_buf *ibuf = widget_get_image(widget);
-   gchar *name = gtk_widget_get_name(widget);
 }
 
 struct color_selection_info
@@ -1731,11 +1651,9 @@ void
 on_select_all_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-   long w, h;
    image_buf *ibuf = widget_get_image(GTK_WIDGET(menuitem));
    set_drawing_tool(ibuf, LASSO);
    image_buf_select_all(ibuf);
-   
 }
    
 
@@ -1800,4 +1718,3 @@ on_about_dialog_button_release_event   (GtkWidget       *widget,
 }
 
 
-
