@@ -28,7 +28,7 @@
 
 GdkPixbuf *clipboard = 0;
 GdkPoint clipboard_pts[MAX_NUM_POINTS]; /* a temporary array for storing points */
-int clipboard_num_pts;
+int clipboard_num_pts = 0;
 
 static void get_image_to_clipboard(image_buf *ibuf)
 {
@@ -49,56 +49,67 @@ static void get_image_to_clipboard(image_buf *ibuf)
 
 void image_buf_cut(image_buf *ibuf)
 {
- 
-   image_buf_copy(ibuf);
-   image_buf_delete(ibuf);  
-
-
+   g_assert(ibuf);
+   if (ibuf->current_tool==LASSO || ibuf->current_tool==POLSELECT)
+   {
+      image_buf_copy(ibuf);
+      image_buf_delete(ibuf);  
+   }
 }
 
 void image_buf_copy(image_buf *ibuf)
 {
-   image_buf_clear_flash(ibuf);
-   get_image_to_clipboard(ibuf);
+   g_assert(ibuf);
+   if (ibuf->current_tool==LASSO || ibuf->current_tool==POLSELECT)
+   {
+      image_buf_clear_flash(ibuf);
+      get_image_to_clipboard(ibuf);
+   }
 }
 
 void image_buf_delete(image_buf *ibuf)
 {
    GdkGCValues gcvalues;
    GdkRectangle clientrect ;
-   assert((ibuf->current_tool == LASSO) || (ibuf->current_tool == POLSELECT));
-   
-   
-   clientrect.x = clientrect.y = 0;
-   clientrect.width = image_buf_width(ibuf);
-   clientrect.height = image_buf_height(ibuf);
-   
-   gdk_gc_get_values(ibuf->gc, &gcvalues);
-   gdk_gc_set_clip_origin(ibuf->gc, 0, 0);
-   gdk_gc_set_clip_rectangle(ibuf->gc, &clientrect);
-   image_buf_clear_flash(ibuf);
-   
-   gdk_gc_set_foreground(ibuf->gc, &(gcvalues.background));
-   
-   gdk_draw_polygon(ibuf->pixmap, ibuf->gc, TRUE, ibuf->pts, ibuf->num_pts);
-   gdk_draw_polygon(ibuf->drawing_area->window, ibuf->gc, TRUE, ibuf->pts, ibuf->num_pts);
-   
-   image_buf_pixmap_to_rgbbuf(ibuf, 0);
+   g_assert(ibuf);
 
-   gdk_gc_set_foreground(ibuf->gc, &(gcvalues.foreground));
+   if (ibuf->current_tool == LASSO || ibuf->current_tool==POLSELECT)
+   {
+      clientrect.x = clientrect.y = 0;
+      clientrect.width = image_buf_width(ibuf);
+      clientrect.height = image_buf_height(ibuf);
    
+      gdk_gc_get_values(ibuf->gc, &gcvalues);
+      gdk_gc_set_clip_origin(ibuf->gc, 0, 0);
+      gdk_gc_set_clip_rectangle(ibuf->gc, &clientrect);
+      image_buf_clear_flash(ibuf);
+   
+      gdk_gc_set_foreground(ibuf->gc, &(gcvalues.background));
+   
+      gdk_draw_polygon(ibuf->pixmap, ibuf->gc, TRUE, ibuf->pts, ibuf->num_pts);
+      gdk_draw_polygon(ibuf->drawing_area->window, ibuf->gc, TRUE, ibuf->pts, ibuf->num_pts);
+   
+      image_buf_pixmap_to_rgbbuf(ibuf, 0);
+
+      gdk_gc_set_foreground(ibuf->gc, &(gcvalues.foreground));
+   } 
 }
 
 
 void image_buf_paste(image_buf *ibuf)
 {
-   image_buf_clear_flash(ibuf);
+   g_assert(ibuf);
+  
+   if (clipboard_num_pts)
+   { 
+      image_buf_clear_flash(ibuf);
 
-   image_buf_enter_paste_mode(ibuf);
-   memcpy(ibuf->pts, clipboard_pts, sizeof(GdkPoint) * clipboard_num_pts);
-   ibuf->num_pts = clipboard_num_pts;
-   image_buf_copy_clipboard_to_region_buf(ibuf);
-   image_buf_put_region_image(ibuf, 0, 0);   
+      image_buf_enter_paste_mode(ibuf);
+      memcpy(ibuf->pts, clipboard_pts, sizeof(GdkPoint) * clipboard_num_pts);
+      ibuf->num_pts = clipboard_num_pts;
+      image_buf_copy_clipboard_to_region_buf(ibuf);
+      image_buf_put_region_image(ibuf, 0, 0);   
+   }
 }
 
 
