@@ -33,7 +33,7 @@ int image_buf_save(image_buf *ibuf, const char *name)
    GdkImlibImage *tmp = 0;
    int rowstride = image_buf_rowstride(ibuf), pixelsize = image_buf_pixelsize(ibuf);
    unsigned char *tmpbuf = calloc(3, image_buf_width(ibuf) * image_buf_height(ibuf)), *p, *p2, *d;
-   
+ 
    g_assert(ibuf);
    g_assert(tmpbuf);
    image_buf_pixmap_to_rgbbuf(ibuf, 0);
@@ -48,7 +48,8 @@ int image_buf_save(image_buf *ibuf, const char *name)
       }
       
    tmp = gdk_imlib_create_image_from_data((tmpbuf), 0, image_buf_width(ibuf), image_buf_height(ibuf));
-   i = gdk_imlib_save_image(tmp, name, 0);
+   /* cast away const for the library call. */
+   i = gdk_imlib_save_image(tmp, (char*)name, 0);
    gdk_imlib_kill_image(tmp);
    free(tmpbuf);
    return i;
