@@ -121,24 +121,6 @@ gauss(void)
     return sum * 5.28596089837e-5 - 3.46410161514;
 }
 
-/*
- * Return a Gaussian (aka normal) random variable, multiplied by 'range'
- * and clamped to [-range, range]. Note: integer return.
- */
-static int 
-gaussclamp(int range)
-{
-    /* The '2.5' is a fudge factor; this value IMHO gives the best result */
-    int g = gauss() * range / 2.5;
-
-    if (g < -range)
-	g = -range;
-    else if (g > range)
-	g = range;
-    return g;
-}
-
-
 static void
 convolve(image_buf *input, image_buf *output, float *mat, int n,
 	 unsigned char *basePixel, gboolean absFlag)
@@ -359,32 +341,25 @@ ImageEmbose(image_buf * input, image_buf *output)
 void
 ImageInvert(image_buf * input, image_buf *output)
 {
-   
-    int i;
-    unsigned char *ip, *op;
-    int count;
+    unsigned char *op;
     int x,y;
     unsigned char *p;
     int width = image_buf_width(input);
     int height = image_buf_height(input);
 
-    
     op = image_buf_rgbbuf(output);
-
     for (y = 0; y < height; y++)
     {
-	for (x = 0; x < width; x++)
-	{
-	    p = ImagePixel(input, x, y);
-	    *op++ = 255 - *p++;
-	    *op++ = 255 - *p++;
-	    *op++ = 255 - *p;
-	    op += image_buf_pixelsize(output) - 3;
-	}
-	op += image_buf_rowstride(output) - width * image_buf_pixelsize(output);
+	   for (x = 0; x < width; x++)
+       {
+	      p = ImagePixel(input, x, y);
+	      *op++ = 255 - *p++;
+	      *op++ = 255 - *p++;
+	      *op++ = 255 - *p;
+	      op += image_buf_pixelsize(output) - 3;
+       }
+      op += image_buf_rowstride(output) - width * image_buf_pixelsize(output);
     }
-
-
 }
 
 void
