@@ -37,7 +37,6 @@
 
 int do_print(image_buf *ibuf)
 {
-   GnomePrinter *printer = NULL;
    GnomePrintContext *pc;
    GnomePrintMaster *gpm = NULL;
    int copies = 1;
@@ -124,6 +123,7 @@ int image_buf_print(image_buf *ibuf, GnomePrintContext *pc)
    double matrix[6] = {1, 0, 0, 1, 0, 0};
    int width = image_buf_width(ibuf);
    int height = image_buf_height(ibuf);
+   image_buf_pixmap_to_rgbbuf(ibuf, 0); /* get the latest version of the image in memory */
    gnome_print_beginpage(pc, ibuf->name);
     
    gnome_print_concat (pc, matrix);
