@@ -30,7 +30,6 @@
 #include "clipboard.h"
 
 
-
 GdkCursor *busy_cursor = 0;
 GdkCursor *arrow_cursor = 0;
 
@@ -218,6 +217,7 @@ void open_canvas(image_buf *ibuf)
       else
          dir = g_get_current_dir();
 
+      /* FIXME: Buffer overflow? */
       sprintf(pathbuf, "%s%c*.*", dir, G_DIR_SEPARATOR);
       gtk_file_selection_set_filename(GTK_FILE_SELECTION(widget), pathbuf);
       g_free(dir);
@@ -440,7 +440,7 @@ static void image_buf_draw_flash(image_buf *ibuf)
 	 gdk_string_extents(ibuf->font, "My", &junk, &junk, &junk, &ascent, &descent);
 	 gdk_string_extents(ibuf->font, ibuf->textbuf, &lbearing, &rbearing, &width, &junk, &junk);
 
-	 gdk_gc_set_function(ibuf->gc, GDK_XOR);
+	 gdk_gc_set_function(ibuf->gc, GDK_INVERT);
 	 gdk_gc_set_line_attributes(ibuf->gc, 2, GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND);
 	 gdk_draw_line(ibuf->drawing_area->window, ibuf->gc, ibuf->llx + rbearing + 2, ibuf->lly + descent, ibuf->llx + rbearing + 2, ibuf->lly - ascent);   
 	 gdk_draw_line(ibuf->pixmap, ibuf->gc, ibuf->llx + rbearing + 2, ibuf->lly + descent, ibuf->llx + rbearing + 2, ibuf->lly - ascent);   
@@ -462,7 +462,7 @@ static void image_buf_draw_flash(image_buf *ibuf)
    
          gdk_gc_set_foreground(ibuf->gc, &white);   
  
-	 gdk_gc_set_function(ibuf->gc, GDK_XOR);
+	 gdk_gc_set_function(ibuf->gc, GDK_INVERT);
 	 gdk_gc_set_line_attributes(ibuf->gc, 1, GDK_LINE_ON_OFF_DASH, GDK_CAP_ROUND, GDK_JOIN_ROUND);
          gdk_gc_set_dashes(ibuf->gc,  ibuf->flash_state / 2, dash_length, sizeof(dash_length));
 	 
@@ -727,14 +727,14 @@ void image_buf_clear(image_buf *ibuf)
    gdk_gc_set_clip_origin(ibuf->gc, 0, 0);
    gdk_gc_set_clip_rectangle(ibuf->gc, &clientrect);
    
-   gdk_gc_set_foreground(ibuf->gc, &(gcvalues.background));
+   gdk_gc_set_foreground(ibuf->gc, &(gcvalues.background)); 
 
    draw_rectangle(ibuf->pixmap, ibuf->gc, TRUE, clientrect.x, clientrect.y, clientrect.width, clientrect.height);
    draw_rectangle(ibuf->drawing_area->window, ibuf->gc, TRUE, clientrect.x, clientrect.y, clientrect.width, clientrect.height);
    image_buf_pixmap_to_rgbbuf(ibuf, 0);
 
    
-   gdk_gc_set_foreground(ibuf->gc, &(gcvalues.foreground));
+    gdk_gc_set_foreground(ibuf->gc, &(gcvalues.foreground)); 
 
 }
 
@@ -859,14 +859,23 @@ void handle_button_press(image_buf *ibuf, int x, int y)
       image_buf_adjust_according_to_points(ibuf, &x, &y);
       image_buf_put_region_image(ibuf, x, y);
       break;
+   
+   case BRUSH:
+      /* brain dead brush */
+      draw_rectangle(ibuf->pixmap, ibuf->gc, TRUE, 
+                     x - erase_size, y - erase_size, x + erase_size, y + erase_size);
+      draw_rectangle(ibuf->drawing_area->window, ibuf->gc, TRUE,
+                     x - erase_size, y - erase_size, x + erase_size, y + erase_size);
+      IMAGE_MODIFIED;
+      break;
                 
    default:
       gdk_beep();
    }
    ibuf->lx = x;
    ibuf->ly = y;
-   ibuf->mx = INT_MIN;
-   ibuf->my = INT_MIN;
+   ibuf->mx = x; /* INT_MIN; */
+   ibuf->my = y; /* INT_MIN; */
 }   
 
 void handle_button_move(image_buf *ibuf, int x, int y)
@@ -931,7 +940,7 @@ void handle_button_move(image_buf *ibuf, int x, int y)
       
    case MULTILINE:
    case LINE:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
       {
          gdk_draw_line(ibuf->drawing_area->window, ibuf->gc, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
@@ -942,7 +951,7 @@ void handle_button_move(image_buf *ibuf, int x, int y)
       break;
       
    case OVAL:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
       {
          draw_oval(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
@@ -952,7 +961,7 @@ void handle_button_move(image_buf *ibuf, int x, int y)
       break;
    
    case ARC:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
       {
          draw_arc(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
@@ -962,26 +971,24 @@ void handle_button_move(image_buf *ibuf, int x, int y)
       break;
    
    case RECTANGLE:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT); 
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
       {
          draw_rectangle(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
       }
       draw_rectangle(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, x, y);
-      gdk_gc_set_function(ibuf->gc, gcvalues.function);  
+      gdk_gc_set_function(ibuf->gc, gcvalues.function); 
       
       break;	 
    
    case ERASE:
-      gdk_gc_set_foreground(ibuf->gc, &(gcvalues.background));
-      draw_rectangle(ibuf->pixmap, ibuf->gc, TRUE, x - erase_size, y - erase_size, x + erase_size, y + erase_size);
-      draw_rectangle(ibuf->drawing_area->window, ibuf->gc, TRUE, x - erase_size, y - erase_size, x + erase_size, y + erase_size);
-      IMAGE_MODIFIED;
-
-      gdk_gc_set_foreground(ibuf->gc, &(gcvalues.foreground));
+      image_buf_paint_interpolate(ibuf, x, y);
       break;
-       
-       
+      
+   case BRUSH: 
+      image_buf_paint_interpolate(ibuf, x, y);
+      break;
+ 
    case PASTE:
       image_buf_adjust_according_to_points(ibuf, &x, &y);
       image_buf_put_region_image(ibuf, x, y);
@@ -1073,7 +1080,7 @@ void handle_button_release(image_buf *ibuf, int x, int y)
       
    case MULTILINE:
    case LINE:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
          gdk_draw_line(ibuf->drawing_area->window, ibuf->gc, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
       
@@ -1084,7 +1091,7 @@ void handle_button_release(image_buf *ibuf, int x, int y)
       break;
       
    case OVAL:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
          draw_oval(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
       
@@ -1095,7 +1102,7 @@ void handle_button_release(image_buf *ibuf, int x, int y)
       break;
    
    case ARC:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
          draw_arc(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
       
@@ -1107,7 +1114,7 @@ void handle_button_release(image_buf *ibuf, int x, int y)
       
       
    case RECTANGLE:
-      gdk_gc_set_function(ibuf->gc, GDK_XOR);
+      gdk_gc_set_function(ibuf->gc, GDK_INVERT);
       if ((ibuf->mx > INT_MIN) && (ibuf->my > INT_MIN))
          draw_rectangle(ibuf->drawing_area->window, ibuf->gc, FALSE, ibuf->lx, ibuf->ly, ibuf->mx, ibuf->my);
       
@@ -1225,7 +1232,7 @@ void handle_key_release(image_buf *ibuf, GdkEventKey *keyevent)
       strcpy(ibuf->textbuf, "");
    }
    
-   gdk_gc_set_function(ibuf->gc, GDK_XOR);
+   gdk_gc_set_function(ibuf->gc, GDK_INVERT);
    gdk_color_white(gdk_rgb_get_cmap(), &white);
    
    gdk_gc_set_foreground(ibuf->gc, &white);   
@@ -1274,6 +1281,64 @@ int handle_timeout(image_buf *ibuf)
    return 1;
 }
 
+void image_buf_paint_interpolate(image_buf *ibuf, int x, int y)
+{
+   double dx;                /* delta x */
+   double dy;                /* delta y */
+   double lastx = ibuf->mx;  
+   double lasty = ibuf->my;
+   double distance;          /* distance moved */
+   double s = 0.0;           /* distance painted */
+   double step = 1.0;        /* paint spacing */
+   double factor;            /* ratio of painted to moved */
+   int    changed = 0;       /* true if image has been changed */
+
+   /* TODO: object-oriented drawing tools */
+   GdkGCValues gcvalues;
+   gdk_gc_get_values(ibuf->gc, &gcvalues);
+
+   /* calculate distance moved: horizontal, vertical, and diag. */
+   dx = (double)(x - ibuf->mx);
+   dy = (double)(y - ibuf->my);
+   distance = sqrt(dx*dx + dy*dy);
+
+   /* return if no movement. */
+   if (distance < 1.0) return;
+
+   /* TODO: object-oriented drawing tools */
+   if (ibuf->current_tool==ERASE)
+   {
+      gdk_gc_set_foreground(ibuf->gc, &(gcvalues.background));
+   }
+
+   /* paint along the movement. */
+   while ( s < distance ) {
+      s += step;          
+      factor = s / distance;
+      x = (int)(lastx + factor * dx);
+      y = (int)(lasty + factor * dy);
+
+      /* TODO: object-oriented drawing tools */
+      draw_rectangle(ibuf->pixmap, ibuf->gc, 
+                     TRUE, x - erase_size, y - erase_size, x + erase_size, y + erase_size);
+      draw_rectangle(ibuf->drawing_area->window, ibuf->gc, 
+                     TRUE, x - erase_size, y - erase_size, x + erase_size, y + erase_size);
+
+      changed = 1;
+   }
+   if (changed) { 
+      IMAGE_MODIFIED;
+   }
+
+   /* TODO: object-oriented drawing tools */
+   if (ibuf->current_tool==ERASE)
+   {
+      gdk_gc_set_foreground(ibuf->gc, &(gcvalues.foreground));
+   }
+}
+
+
+
 void image_buf_select_all(image_buf *ibuf)
 {
    long w, h;
